@@ -102,7 +102,7 @@ void AIEntity::getShoot()
 
 QIcon AIEntity::icon() const
 {
-    return QIcon::fromTheme( QLatin1String( "roll" ));
+    return QIcon::fromTheme( QStringLiteral( "roll" ));
 }
 
 #include "moc_aientity.cpp"
